@@ -1,12 +1,12 @@
 from hyperfoil.clients import RunClient, BenchmarkClient
-from hyperfoil.resources import Run, Benchmark
+from hyperfoil.resources import RunResource, BenchmarkResource
 
 
 def test_create(benchmark, benchmark_yaml):
     assert benchmark.create(params=benchmark_yaml)
     mark = benchmark.read(benchmark_yaml['name'])
     assert mark.entity == benchmark_yaml
-    assert isinstance(mark, Benchmark)
+    assert isinstance(mark, BenchmarkResource)
     assert isinstance(mark.client, BenchmarkClient)
 
 
@@ -23,7 +23,7 @@ def test_start(benchmark, benchmark_yaml):
     run = benchmark.start(benchmark_yaml['name'])
     assert run
     assert run['id']
-    assert isinstance(run, Run)
+    assert isinstance(run, RunResource)
     assert isinstance(run.client, RunClient)
 
 
@@ -37,5 +37,5 @@ def test_benchmark_with_file(benchmark, benchmark_file):
     run = benchmark.start(benchmark_file['name'])
     assert run
     assert run['id']
-    assert isinstance(run, Run)
+    assert isinstance(run, RunResource)
     assert isinstance(run.client, RunClient)
